==> apache-camel-3.4.1-src.zip: apache-camel-3.4.1/core/camel-core/src/test/java/org/apache/camel/processor/RouteTopLevelMisconfiguredTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertTrue;
import static org.junit.jupiter.api.Assertions.fail;

public class RouteTopLevelMisconfiguredTest extends ContextTestSupport {

    @Override
    public boolean isUseRouteBuilder() {
        return false;
    }

    @Test
    public void testInvalidOnException() throws Exception {
        try {
            context.addRoutes(new RouteBuilder() {
                @Override
                public void configure() throws Exception {
                    from("direct:start").split(body()).onException(IllegalArgumentException.class).to("mock:illegal").end().to("mock:split").end();
                }
            });
            fail("Should fail");
        } catch (IllegalArgumentException e) {
            assertTrue(e.getMessage().startsWith("The output must be added as top-level on the route."));
        }
    }

    @Test
    public void testInvalidOnCompletion() throws Exception {
        try {
            context.addRoutes(new RouteBuilder() {
                @Override
                public void configure() throws Exception {
                    from("direct:start").split(body()).onCompletion().to("mock:done").end().to("mock:split").end();
                }
            });
            fail("Should fail");
        } catch (IllegalArgumentException e) {
            assertTrue(e.getMessage().startsWith("The output must be added as top-level on the route."));
        }
    }

    @Test
    public void testInvalidTransacted() throws Exception {
        try {
            context.addRoutes(new RouteBuilder() {
                @Override
                public void configure() throws Exception {
                    from("direct:start").split(body()).transacted().to("mock:split").end();
                }
            });
            fail("Should fail");
        } catch (IllegalArgumentException e) {
            assertTrue(e.getMessage().startsWith("The output must be added as top-level on the route."));
        }
    }
}

==> apache-camel-4.10.8-src.zip: apache-camel-4.10.8/core/camel-core/src/test/java/org/apache/camel/processor/RouteTopLevelMisconfiguredTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertTrue;
import static org.junit.jupiter.api.Assertions.fail;

public class RouteTopLevelMisconfiguredTest extends ContextTestSupport {

    @Override
    public boolean isUseRouteBuilder() {
        return false;
    }

    @Test
    public void testInvalidOnException() throws Exception {
        try {
            context.addRoutes(new RouteBuilder() {
                @Override
                public void configure() {
                    from("direct:start").split(body()).onException(IllegalArgumentException.class).to("mock:illegal").end()
                            .to("mock:split").end();
                }
            });
            fail("Should fail");
        } catch (IllegalArgumentException e) {
            assertTrue(e.getMessage().startsWith("The output must be added as top-level on the route."));
        }
    }

    @Test
    public void testInvalidOnCompletion() throws Exception {
        try {
            context.addRoutes(new RouteBuilder() {
                @Override
                public void configure() {
                    from("direct:start").split(body()).onCompletion().to("mock:done").end().to("mock:split").end();
                }
            });
            fail("Should fail");
        } catch (IllegalArgumentException e) {
            assertTrue(e.getMessage().startsWith("The output must be added as top-level on the route."));
        }
    }

    @Test
    public void testInvalidTransacted() throws Exception {
        try {
            context.addRoutes(new RouteBuilder() {
                @Override
                public void configure() {
                    from("direct:start").split(body()).transacted().to("mock:split").end();
                }
            });
            fail("Should fail");
        } catch (IllegalArgumentException e) {
            assertTrue(e.getMessage().startsWith("The output must be added as top-level on the route."));
        }
    }
}
